@@ -59,7 +59,7 @@ void dbus_connection_setup_with_g_main (DBusConnection *connection, GMainContext
 #define DEST_PORT 5555
 #define SCAN_PORT 3483
 #define UPDATE_RATE 400 /* in ms */
-#define SAMPLES_AFTER_EVENT 10
+#define SAMPLES_AFTER_EVENT 5
 
 #define GCONF_KEY_PREFIX "/apps/maemo/tabletbridge"
 #define GCONF_KEY_NAME_ONE   GCONF_KEY_PREFIX"/name_one"
@@ -426,23 +426,21 @@ static gboolean periodic_update(gpointer data)
     
     if ((activity_counter < SAMPLES_AFTER_EVENT) ||
        ((activity_counter % SAMPLES_AFTER_EVENT) == 0)) {
-    
-    /* request a screen update */
-    if (send_request(msg) != strlen(msg)) {
-      hildon_banner_show_information(GTK_WIDGET(window), NULL,
-                             "periodic_update: send failed");
-      return FALSE;
-    }
-
-    screen_data = get_response("GetDisplayData: data bytes:", 
+	    /* request a screen update */
+	    if (send_request(msg) != strlen(msg)) {
+		    hildon_banner_show_information(GTK_WIDGET(window), NULL,
+				    "periodic_update: send failed");
+		    return FALSE;
+	    }
+	    
+	    screen_data = get_response("GetDisplayData: data bytes:", 
     				displays[display_idx].offset);
-    if (screen_data != NULL) {
-      update_pixbuf(screen_data);
-    } else {
-      my_printf("%s(): return FALSE\n", __PRETTY_FUNCTION__);
-      return FALSE;
-    }
-    
+	    if (screen_data != NULL) {
+		    update_pixbuf(screen_data);
+	    } else {
+		    my_printf("%s(): return FALSE\n", __PRETTY_FUNCTION__);
+		    return FALSE;
+	    }
     }
     activity_counter++;
     
@@ -1478,6 +1476,7 @@ gint main(gint argc, gchar *argv[])
                             displays[display_idx].width*displays[display_idx].horiz_scale,
                             displays[display_idx].height*displays[display_idx].vertical_scale);
     screen = gtk_image_new_from_pixbuf(pixbuf);
+    clear_pixbuf();
 
     //gtk_container_add(GTK_CONTAINER(window), screen);
 
